@@ -26,7 +26,6 @@
  * demonstrates how to handle NV-CONTROL events.
  */
 
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -503,7 +502,6 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_CONNECTED_DISPLAYS),
     MAKE_ENTRY(NV_CTRL_ENABLED_DISPLAYS),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK),
-    MAKE_ENTRY(NV_CTRL_FRAMELOCK_MASTER),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK_POLARITY),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK_SYNC_DELAY),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK_SYNC_INTERVAL),
@@ -553,8 +551,6 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_BUS_RATE),
     MAKE_ENTRY(NV_CTRL_XV_SYNC_TO_DISPLAY),
     MAKE_ENTRY(NV_CTRL_ASSOCIATED_DISPLAY_DEVICES),
-    MAKE_ENTRY(NV_CTRL_FRAMELOCK_SLAVES),
-    MAKE_ENTRY(NV_CTRL_FRAMELOCK_MASTERABLE),
     MAKE_ENTRY(NV_CTRL_PROBE_DISPLAYS),
     MAKE_ENTRY(NV_CTRL_REFRESH_RATE),
     MAKE_ENTRY(NV_CTRL_CURRENT_SCANLINE),
@@ -587,7 +583,6 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_DISPLAYPORT_LINK_RATE),
     MAKE_ENTRY(NV_CTRL_STEREO_EYES_EXCHANGE),
     MAKE_ENTRY(NV_CTRL_NO_SCANOUT),
-    MAKE_ENTRY(NV_CTRL_FRAMELOCK_SLAVEABLE ),
     MAKE_ENTRY(NV_CTRL_X_SERVER_UNIQUE_ID),
     MAKE_ENTRY(NV_CTRL_PIXMAP_CACHE),
     MAKE_ENTRY(NV_CTRL_PIXMAP_CACHE_ROUNDING_SIZE_KB),
@@ -659,11 +654,9 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_FRAMELOCK_DISPLAY_CONFIG),
     MAKE_ENTRY(NV_CTRL_TOTAL_DEDICATED_GPU_MEMORY),
     MAKE_ENTRY(NV_CTRL_USED_DEDICATED_GPU_MEMORY),
-    MAKE_ENTRY(NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_IMMEDIATE),
-    MAKE_ENTRY(NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_REBOOT),
     MAKE_ENTRY(NV_CTRL_DPY_HDMI_3D),
     MAKE_ENTRY(NV_CTRL_BASE_MOSAIC),
-    MAKE_ENTRY(NV_CTRL_MULTIGPU_MASTER_POSSIBLE),
+    MAKE_ENTRY(NV_CTRL_MULTIGPU_PRIMARY_POSSIBLE),
     MAKE_ENTRY(NV_CTRL_GPU_POWER_MIZER_DEFAULT_MODE),
     MAKE_ENTRY(NV_CTRL_XV_SYNC_TO_DISPLAY_ID),
     MAKE_ENTRY(NV_CTRL_CURRENT_XV_SYNC_TO_DISPLAY_ID),
